/*
    Created by Quo
*/
 


-- UNIT MOVEMENT (ROCKETBOOTS)
-- Give every unit 1 additional move point
UPDATE Units SET BaseMoves=BaseMoves + 1 ;


-- No more urban defenses
DELETE FROM CivicModifiers WHERE CivicType='CIVIC_CIVIL_ENGINEERING' AND ModifierId='CIVIL_ENGINEERING_URBAN_DEFENSES' ;


-- TILES

-- OASIS
-- Make the area adjacent to an Oasis worth settling, can result in some amazing locations if you get lucky
INSERT INTO Feature_AdjacentYields (FeatureType, YieldType, YieldChange) VALUES ('FEATURE_OASIS', 'YIELD_FOOD', '2') ;
INSERT INTO Feature_AdjacentYields (FeatureType, YieldType, YieldChange) VALUES ('FEATURE_OASIS', 'YIELD_GOLD', '1') ;


-- Adjust which tiles can appear next to the oasis
INSERT INTO Feature_NotAdjacentTerrains
	(FeatureType,		TerrainType)
VALUES	('FEATURE_OASIS',	'TERRAIN_GRASS_HILLS'),
	('FEATURE_OASIS',	'TERRAIN_PLAINS_HILLS') ;



-- Make the Oasis appear in Tundra! Why not?
INSERT INTO Feature_ValidTerrains 
	(FeatureType,		TerrainType)
VALUES	('FEATURE_OASIS',	'TERRAIN_TUNDRA') ;



-- FISHING BOATS
-- Add 1 gold
UPDATE Improvement_YieldChanges SET YieldChange='1' WHERE ImprovementType='IMPROVEMENT_FISHING_BOATS' AND YieldType='YIELD_GOLD' ;


-- SEA RESOURCES
-- Add 1 to the respective yield of each sea resource
UPDATE Resource_YieldChanges SET YieldChange='2' WHERE ResourceType ='RESOURCE_FISH' AND YieldType='YIELD_FOOD' ;
UPDATE Resource_YieldChanges SET YieldChange='2' WHERE ResourceType ='RESOURCE_PEARLS' AND YieldType='YIELD_FAITH' ;
INSERT INTO Resource_YieldChanges (ResourceType, YieldType, YieldChange) VALUES ('RESOURCE_WHALES', 'YIELD_FAITH', '1') ;
INSERT INTO Resource_YieldChanges (ResourceType, YieldType, YieldChange) VALUES ('RESOURCE_CRABS', 'YIELD_CULTURE', '1') ;


-- ICE
-- Remove Ice completely from the map, to make sure the globe can be circled with boats
DELETE FROM Feature_ValidTerrains WHERE FeatureType='FEATURE_ICE' ;



-- ASSORTED RESOURCES
-- Allow Deer to appear near rivers, because deer live near rivers. Make them somewhat more common overall.
UPDATE Resources SET NoRiver='0', Frequency='6' WHERE ResourceType='RESOURCE_DEER' ;


-- Decrease Stone
UPDATE Resources SET Frequency=Frequency*0.5 WHERE ResourceType='RESOURCE_STONE' ;




-- STRATEGIC RESOURCES
-- Increase strategic resources by x2.5
UPDATE Resources SET Frequency=Frequency*2.5 WHERE ResourceClassType= 'RESOURCECLASS_STRATEGIC';

-- Make Iron not suck
UPDATE Resource_YieldChanges SET YieldChange='3' WHERE ResourceType='RESOURCE_IRON' AND YieldType='YIELD_SCIENCE' ;


-- Uranium now appears in water
INSERT INTO Resource_ValidTerrains
	(ResourceType,		TerrainType)
VALUES	('RESOURCE_URANIUM',	'TERRAIN_COAST')  ;

 


-- BORDER EXPANSION RATE
-- Make borders pop faster
-- To make borders pop faster, give the Palace a global bonus to border expansion

INSERT INTO Modifiers
	(ModifierID, 			ModifierType, 					RunOnce, 	Permanent, 	OwnerRequirementSetId, 	SubjectRequirementSetId)
VALUES	('QUO_CULTURE_BORDER_DISCOUNT', 'MODIFIER_ALL_CITIES_CULTURE_BORDER_EXPANSION', 0, 		0, 		NULL,			NULL) ;


INSERT INTO ModifierArguments
	(ModifierID,			Name,		Type, 			Value,	Extra)
VALUES	('QUO_CULTURE_BORDER_DISCOUNT', 'Amount', 	'ARGTYPE_IDENTITY', 	'50',	NULL) ;


INSERT INTO BuildingModifiers
	(BuildingType,		ModifierID)
VALUES	('BUILDING_PALACE', 	'QUO_CULTURE_BORDER_DISCOUNT') ;




-- ENCAMPMENT
-- The encampment no longer has any tech pre-reqs.
UPDATE Districts SET PrereqTech=NULL WHERE DistrictType='DISTRICT_ENCAMPMENT' ;

-- Walls now require an encampment
UPDATE Buildings SET PrereqDistrict='DISTRICT_ENCAMPMENT' WHERE BuildingType='BUILDING_WALLS' ;
UPDATE Buildings SET PrereqDistrict='DISTRICT_ENCAMPMENT' WHERE BuildingType='BUILDING_STAR_FORT' ;

-- Move the stable and barracks up a tech
UPDATE Buildings SET PrereqTech='TECH_MINING' WHERE BuildingType='BUILDING_BARRACKS' ;
UPDATE Buildings SET PrereqTech='TECH_ANIMAL_HUSBANDRY', Cost='80' WHERE BuildingType='BUILDING_STABLE' ;


-- HOLY SITE
-- Move it off the tech tree to the civic tree, in the Mysticism civic
UPDATE Districts SET PrereqTech=NULL, PrereqCivic='CIVIC_MYSTICISM' WHERE DistrictType='DISTRICT_HOLY_SITE'; 
UPDATE Districts SET PrereqTech=NULL, PreReqCivic='CIVIC_MYSTICISM' WHERE DistrictType='DISTRICT_LAVRA' ;


-- HARBOR, DOCK YARD
-- Unlock at Astrology, replacing where Holy site used to unlock. This is a little strange, but allows AI to grab this district faster.
UPDATE Districts SET PrereqTech='TECH_ASTROLOGY' WHERE DistrictType='DISTRICT_HARBOR'; 
UPDATE Districts SET PrereqTech='TECH_ASTROLOGY' WHERE DistrictType='DISTRICT_ROYAL_NAVY_DOCKYARD'; 


-- HARBOR ADJACENCIES
-- Double gold value
UPDATE Adjacency_YieldChanges SET YieldChange='2' WHERE ID='SeaResource_Gold' ;  


-- Add adjacency gold/hammers for city centers
INSERT INTO Adjacency_YieldChanges 
	(ID,				Description,				YieldType,		YieldChange,	TilesRequired,	OtherDistrictAdjacent,	AdjacentSeaResource,	AdjacentTerrain,	AdjacentFeature,	AdjacentRiver,	AdjacentWonder,	AdjacentNaturalWonder,	AdjacentImprovement,	AdjacentDistrict,	PrereqCivic,	PrereqTech,	ObsoleteCivic,	ObsoleteTech,	AdjacentResource)
VALUES	('QUO_SeaResource_Hammers',	'QUO_LOC_DISTRICT_SEARESOURCE_HAMMERS',	'YIELD_PRODUCTION',	2,		1,		0,			1,			NULL,			NULL,			0,		0,		0,			NULL,			NULL,			NULL,		NULL,		NULL,		NULL,		0) ,
	('QUO_Coast_Gold',		'QUO_LOC_DISTRICT_COAST_GOLD',		'YIELD_GOLD',		1,		1,		0,			0,			'TERRAIN_COAST',	NULL,			0,		0,		0,			NULL,			NULL,			NULL,		'TECH_SAILING',		NULL,		NULL,		0) ,
	('QUO_Coast_Gold_2',		'QUO_LOC_DISTRICT_COAST_GOLD',		'YIELD_GOLD',		1,		1,		0,			0,			'TERRAIN_COAST',	NULL,			0,		0,		0,			NULL,			NULL,			NULL,		'TECH_CARTOGRAPHY',		NULL,		NULL,		0) ,
	('QUO_Coast_Hammers',		'QUO_LOC_DISTRICT_COAST_HAMMERS',	'YIELD_PRODUCTION',	1,		2,		0,			0,			'TERRAIN_COAST',	NULL,			0,		0,		0,			NULL,			NULL,			NULL,		'TECH_CELESTIAL_NAVIGATION',		NULL,		NULL,		0); 			


-- CITY CENTER
-- Give bonuses for coast adjacencies
INSERT INTO District_Adjacencies
	(DistrictType,			YieldChangeID)
VALUES	('DISTRICT_CITY_CENTER',	'QUO_Coast_Gold') ,
 	('DISTRICT_CITY_CENTER',	'QUO_Coast_Gold_2'),  
	('DISTRICT_CITY_CENTER',	'QUO_Coast_Hammers') ;



-- GOVERNMENT

-- Chiefdom 
-- Remove the economic policy slot and add a wildcard slot
UPDATE Government_SlotCounts SET NumSlots=0 WHERE GovernmentType='GOVERNMENT_CHIEFDOM' AND GovernmentSlotType='SLOT_ECONOMIC' ;

INSERT INTO Government_SlotCounts 
		(GovernmentType, GovernmentSlotType, NumSlots)
VALUES 	('GOVERNMENT_CHIEFDOM', 'SLOT_WILDCARD', 1) ;




-- BUILDINGS

-- MONUMENTS
-- Because borders pop faster, the Monument is now a vital building. To balance with Rome, I cut the production cost of Monuments in half.
UPDATE Buildings SET Cost=Cost*0.5 WHERE BuildingType='BUILDING_MONUMENT' ;	


--PALACE
--The Palace has the effect of walls
UPDATE Buildings SET OuterDefenseHitPoints='40', OuterDefenseStrength='2' WHERE BuildingType='BUILDING_PALACE' ;


-- STONEHENGE
-- Move it to Masonry to delay how fast AI can grab it.
UPDATE Buildings SET PrereqTech='TECH_MASONRY' WHERE BuildingType='BUILDING_STONEHENGE' ;


-- SEWER
-- Now available at Mathematics, cost reduced
UPDATE Buildings SET PrereqTech='TECH_MATHEMATICS', Cost=Cost*.07 WHERE BuildingType='BUILDING_SEWER' ;




-- DISTRICTS

-- AQUEDUCT
-- Aqueducts/Baths provide Great Engineer points
INSERT INTO District_GreatPersonPoints 
	(DistrictType, 		GreatPersonClassType, 		PointsPerTurn)
VALUES	('DISTRICT_AQUEDUCT',	'GREAT_PERSON_CLASS_ENGINEER',	'1' ) ,
	('DISTRICT_BATH',	'GREAT_PERSON_CLASS_ENGINEER',	'1' ) ;





-- INDIVIDUAL UNITS


-- SUPPORT UNITS
-- Cut cost of Support units in half
UPDATE Units SET Cost=Cost*0.5 WHERE FormationClass='FORMATION_CLASS_SUPPORT' ;


-- SWORDSMEN
-- Make Swordsmen somewhat better compared to horse units
UPDATE Units SET Combat='40' WHERE UnitType='UNIT_SWORDSMAN' ;


-- MUSKETMEN
-- Musketmen no longer require Niter, because this destroys the AI
UPDATE Units SET StrategicResource=NULL WHERE UnitType='UNIT_MUSKETMAN' ;


-- SCOUTS
-- Scouts start at level 2 instead of level 1, and get +1 vision
UPDATE Units SET InitialLevel='2', BaseSightRange='3' WHERE UnitType='UNIT_SCOUT' ;


--SETTLER STEALING
-- Settler escapes on contact
UPDATE Units SET CanRetreatWhenCaptured='1' WHERE UnitType='UNIT_SETTLER' ;


-- SIEGE
-- All siege units have a range of at least 3
UPDATE Units SET Range=3 WHERE UnitType='UNIT_CATAPULT' ;
UPDATE Units SET Range=3 WHERE UnitType='UNIT_BOMBARD' ;
UPDATE Units SET Range=3 WHERE UnitType='UNIT_ARTILLERY' ;


--- TECHS


-- ASTROLOGY
-- Scouts embark at Astrology
UPDATE Technologies SET EmbarkUnitType='UNIT_SCOUT' WHERE TechnologyType='TECH_ASTROLOGY' ;

-- Increase the cost of the tech somewhat given all the changes made to it
UPDATE Technologies SET Cost='80' WHERE TechnologyType='TECH_ASTROLOGY' ;


